@@ -26,9 +26,10 @@
 #include <assert.h>
 #include <string.h>
 
+#include <libtracker-common/tracker-parser.h>
+
 #include "tracker-fts-tokenizer.h"
 #include "tracker-fts-config.h"
-#include "tracker-parser.h"
 #include "fts3_tokenizer.h"
 
 typedef struct TrackerTokenizer TrackerTokenizer;
