@@ -34,22 +34,16 @@
 #include <gio/gunixfdlist.h>
 #include <gio/gunixinputstream.h>
 
-#include <libtracker-common/tracker-dbus.h>
-#include <libtracker-common/tracker-date-time.h>
-#include <libtracker-common/tracker-ontologies.h>
-#include <libtracker-common/tracker-type-utils.h>
-#include <libtracker-common/tracker-utils.h>
-#include <libtracker-common/tracker-file-utils.h>
-#include <libtracker-common/tracker-storage.h>
+#include <libtracker-common/tracker-common.h>
+#include <libtracker-sparql/tracker-ontologies.h>
+#include <libtracker-extract/tracker-extract.h>
 
 #include <libtracker-data/tracker-db-manager.h>
 
-#include <libtracker-extract/tracker-module-manager.h>
-#include <libtracker-extract/tracker-extract-client.h>
-
 #include "tracker-power.h"
 #include "tracker-miner-files.h"
 #include "tracker-config.h"
+#include "tracker-storage.h"
 
 #define DISK_SPACE_CHECK_FREQUENCY 10
 #define SECONDS_PER_DAY 86400
@@ -684,7 +678,7 @@ ensure_mount_point_exists (TrackerMinerFiles *miner,
 
 		/* Create a nfo:Folder for the mount point */
 		g_string_append_printf (accumulator,
-		                        "INSERT SILENT INTO <" TRACKER_MINER_FS_GRAPH_URN "> {"
+		                        "INSERT SILENT INTO <" TRACKER_OWN_GRAPH_URN "> {"
 		                        " _:file a nfo:FileDataObject, nie:InformationElement, nfo:Folder ; "
 		                        "        nie:isStoredAs _:file ; "
 		                        "        nie:url \"%s\" ; "
@@ -924,7 +918,7 @@ init_mount_points (TrackerMinerFiles *miner_files)
 	/* Make sure the root partition is always set to mounted, as GIO won't
 	 * report it as a proper mount */
 	g_hash_table_insert (volumes,
-	                     g_strdup (TRACKER_NON_REMOVABLE_MEDIA_DATASOURCE_URN),
+	                     g_strdup (TRACKER_DATASOURCE_URN_NON_REMOVABLE_MEDIA),
 	                     GINT_TO_POINTER (VOLUME_MOUNTED));
 
 	while (tracker_sparql_cursor_next (cursor, NULL, NULL)) {
@@ -935,7 +929,7 @@ init_mount_points (TrackerMinerFiles *miner_files)
 
 		urn = tracker_sparql_cursor_get_string (cursor, 0, NULL);
 
-		if (strcmp (urn, TRACKER_NON_REMOVABLE_MEDIA_DATASOURCE_URN) == 0) {
+		if (strcmp (urn, TRACKER_DATASOURCE_URN_NON_REMOVABLE_MEDIA) == 0) {
 			/* Report non-removable media to be mounted by HAL as well */
 			state |= VOLUME_MOUNTED;
 		}
@@ -953,7 +947,7 @@ init_mount_points (TrackerMinerFiles *miner_files)
 		gint state;
 
 		uuid = u->data;
-		non_removable_device_urn = g_strdup_printf (TRACKER_DATASOURCE_URN_PREFIX "%s", uuid);
+		non_removable_device_urn = g_strdup_printf (TRACKER_PREFIX_DATASOURCE_URN "%s", uuid);
 
 		state = GPOINTER_TO_INT (g_hash_table_lookup (volumes, non_removable_device_urn));
 		state |= VOLUME_MOUNTED;
@@ -973,7 +967,7 @@ init_mount_points (TrackerMinerFiles *miner_files)
 			gint state;
 
 			uuid = u->data;
-			removable_device_urn = g_strdup_printf (TRACKER_DATASOURCE_URN_PREFIX "%s", uuid);
+			removable_device_urn = g_strdup_printf (TRACKER_PREFIX_DATASOURCE_URN "%s", uuid);
 
 			state = GPOINTER_TO_INT (g_hash_table_lookup (volumes, removable_device_urn));
 			state |= VOLUME_MOUNTED;
@@ -1000,10 +994,10 @@ init_mount_points (TrackerMinerFiles *miner_files)
 
 			/* Note: is there any case where the urn doesn't have our
 			 *  datasource prefix? */
-			if (g_str_has_prefix (urn, TRACKER_DATASOURCE_URN_PREFIX)) {
+			if (g_str_has_prefix (urn, TRACKER_PREFIX_DATASOURCE_URN)) {
 				const gchar *uuid;
 
-				uuid = urn + strlen (TRACKER_DATASOURCE_URN_PREFIX);
+				uuid = urn + strlen (TRACKER_PREFIX_DATASOURCE_URN);
 				mount_point = tracker_storage_get_mount_point_for_uuid (priv->storage, uuid);
 				type = tracker_storage_get_type_for_uuid (priv->storage, uuid);
 			}
@@ -1154,7 +1148,7 @@ mount_point_removed_cb (TrackerStorage *storage,
 	gchar *urn;
 	GFile *mount_point_file;
 
-	urn = g_strdup_printf (TRACKER_DATASOURCE_URN_PREFIX "%s", uuid);
+	urn = g_strdup_printf (TRACKER_PREFIX_DATASOURCE_URN "%s", uuid);
 	g_debug ("Mount point removed for URN '%s'", urn);
 
 	mount_point_file = g_file_new_for_path (mount_point);
@@ -1190,7 +1184,7 @@ mount_point_added_cb (TrackerStorage *storage,
 
 	priv = TRACKER_MINER_FILES_GET_PRIVATE (miner);
 
-	urn = g_strdup_printf (TRACKER_DATASOURCE_URN_PREFIX "%s", uuid);
+	urn = g_strdup_printf (TRACKER_PREFIX_DATASOURCE_URN "%s", uuid);
 	g_message ("Mount point added for URN '%s'", urn);
 
 	if (removable && !priv->index_removable_devices) {
@@ -1952,10 +1946,10 @@ miner_files_add_to_datasource (TrackerMinerFiles    *mf,
 	removable_device_uuid = tracker_storage_get_uuid_for_file (priv->storage, file);
 
 	if (removable_device_uuid) {
-		removable_device_urn = g_strdup_printf (TRACKER_DATASOURCE_URN_PREFIX "%s",
+		removable_device_urn = g_strdup_printf (TRACKER_PREFIX_DATASOURCE_URN "%s",
 		                                        removable_device_uuid);
 	} else {
-		removable_device_urn = g_strdup (TRACKER_NON_REMOVABLE_MEDIA_DATASOURCE_URN);
+		removable_device_urn = g_strdup (TRACKER_DATASOURCE_URN_NON_REMOVABLE_MEDIA);
 	}
 
 	urn = miner_files_get_file_urn (mf, file, &is_iri);
@@ -2070,7 +2064,7 @@ sparql_builder_finish (ProcessFileData *data,
 		GString *queries;
 		gchar *removable_device_urn, *uri;
 
-		removable_device_urn = g_strdup_printf (TRACKER_DATASOURCE_URN_PREFIX "%s", uuid);
+		removable_device_urn = g_strdup_printf (TRACKER_PREFIX_DATASOURCE_URN "%s", uuid);
 		uri = g_file_get_uri (G_FILE (data->file));
 		queries = g_string_new ("");
 
@@ -2140,7 +2134,7 @@ process_file_cb (GObject      *object,
 	data->mime_type = g_strdup (mime_type);
 
 	tracker_sparql_builder_insert_silent_open (sparql, NULL);
-	tracker_sparql_builder_graph_open (sparql, TRACKER_MINER_FS_GRAPH_URN);
+	tracker_sparql_builder_graph_open (sparql, TRACKER_OWN_GRAPH_URN);
 
 	if (is_iri) {
 		tracker_sparql_builder_subject_iri (sparql, urn);
@@ -2300,7 +2294,7 @@ process_file_attributes_cb (GObject      *object,
 	tracker_sparql_builder_object_variable (sparql, "lastmodified");
 	tracker_sparql_builder_where_close (sparql);
 	tracker_sparql_builder_insert_open (sparql, NULL);
-	tracker_sparql_builder_graph_open (sparql, TRACKER_MINER_FS_GRAPH_URN);
+	tracker_sparql_builder_graph_open (sparql, TRACKER_OWN_GRAPH_URN);
 	tracker_sparql_builder_subject_iri (sparql, urn);
 	time_ = g_file_info_get_attribute_uint64 (file_info, G_FILE_ATTRIBUTE_TIME_MODIFIED);
 	tracker_sparql_builder_predicate (sparql, "nfo:fileLastModified");
@@ -2320,7 +2314,7 @@ process_file_attributes_cb (GObject      *object,
 	tracker_sparql_builder_object_variable (sparql, "lastaccessed");
 	tracker_sparql_builder_where_close (sparql);
 	tracker_sparql_builder_insert_open (sparql, NULL);
-	tracker_sparql_builder_graph_open (sparql, TRACKER_MINER_FS_GRAPH_URN);
+	tracker_sparql_builder_graph_open (sparql, TRACKER_OWN_GRAPH_URN);
 	tracker_sparql_builder_subject_iri (sparql, urn);
 	time_ = g_file_info_get_attribute_uint64 (file_info, G_FILE_ATTRIBUTE_TIME_ACCESS);
 	tracker_sparql_builder_predicate (sparql, "nfo:fileLastAccessed");
@@ -2404,7 +2398,7 @@ miner_files_ignore_next_update_file (TrackerMinerFS       *fs,
 	 * should NEVER be marked as tracker:writeback in the ontology! (else you break
 	 * the tracker-writeback feature) */
 
-	tracker_sparql_builder_insert_silent_open (sparql, TRACKER_MINER_FS_GRAPH_URN);
+	tracker_sparql_builder_insert_silent_open (sparql, TRACKER_OWN_GRAPH_URN);
 
 	tracker_sparql_builder_subject_variable (sparql, "urn");
 	tracker_sparql_builder_predicate (sparql, "a");
