@@ -1492,12 +1492,12 @@ discoverer_init_and_run (MetadataExtractor *extractor,
 	if (error) {
 		if (gst_discoverer_info_get_result(info) == GST_DISCOVERER_MISSING_PLUGINS) {
 			required_plugins_message = get_discoverer_required_plugins_message (info);
-			g_warning ("Missing a GStreamer plugin for %s. %s", uri,
+			g_message ("Missing a GStreamer plugin for %s. %s", uri,
 			           required_plugins_message);
 			g_free (required_plugins_message);
 		} else {
-			g_warning ("Call to gst_discoverer_discover_uri() failed: %s",
-			           error->message);
+			g_warning ("Call to gst_discoverer_discover_uri(%s) failed: %s",
+			           uri, error->message);
 		}
 		gst_discoverer_info_unref (info);
 		g_error_free (error);
